@@ -1,7 +1,6 @@
 """ Helper functions. """
 import configparser
 import re
-from typing import Union
 
 
 def read_config(filename: str) -> configparser.ConfigParser:
@@ -11,7 +10,7 @@ def read_config(filename: str) -> configparser.ConfigParser:
     return conf
 
 
-def format_msg(msg_in: Union[str, list]) -> str:
+def format_msg(msg_in: str | list) -> str:
     msg = msg_in[0] if isinstance(msg_in, list) else msg_in
     if not msg.endswith("."):
         msg += "."
@@ -30,9 +29,9 @@ def create_expected_received_msg(variable: str, expected: str, received: str) ->
 
 def create_out_of_bounds_msg(
     variable: str,
-    lower_limit: Union[str, int, float],
-    upper_limit: Union[str, int, float],
-    value: Union[str, int, float],
+    lower_limit: str | int | float,
+    upper_limit: str | int | float,
+    value: str | int | float,
 ) -> str:
     return (
         f"Value {format_value(value)} exceeds expected limits {format_value(lower_limit)} ... "
@@ -40,5 +39,5 @@ def create_out_of_bounds_msg(
     )
 
 
-def format_value(value: Union[str, int, float]) -> str:
+def format_value(value: str | int | float) -> str:
     return "{:,g}".format(float(value))
